Minimal HTTP host for runtime health, status, and command ingress.
Structs
- Http
ApiConfig - Runtime HTTP listener and request-size configuration.
- Http
Command Auth - Bearer-token requirements and verifier for HTTP Runtime routes.
- Request
Validation Details - Details of an incoming query or command request used to verify its integrity.
- Runtime
Http Host - Embedded HTTP host for stable Runtime health, status, command, and query routes.
- Runtime
Http State Parts - Optional shared state used to compose a
RuntimeHttpHost. - Runtime
Static Info - Non-sensitive Runtime facts exposed by health and status routes.
- Sync
LogView Error - Redacted failure to observe synchronization-log state.
Enums
- Command
Capability Policy Error - Stable reason a capability policy rejected an invocation.
Traits
- Command
Capability Policy - Authorizes application invocations against capability and leadership policy.
- Command
Token Verifier - Verifies command- and query-scoped bearer tokens.
- Sync
LogView - Read-only synchronization-log metrics exposed to the HTTP host.