#[non_exhaustive]pub struct HttpRoutingGenerationsSnapshot {
pub active: HttpRoutingGenerationSnapshot,
pub retiring: Option<HttpRoutingGenerationSnapshot>,
pub retained_generations: usize,
pub max_retained_generations: usize,
}Expand description
Bounded ownership snapshot for active and retiring routing generations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.active: HttpRoutingGenerationSnapshotGeneration selected for new requests.
retiring: Option<HttpRoutingGenerationSnapshot>Previous or failed generation retained only until its requests finish.
retained_generations: usizeNumber of generations retained by the reload owner.
max_retained_generations: usizeHard owner limit: one active generation and one retiring generation.