pub struct RuntimeStaticInfo {Show 20 fields
pub app_id: String,
pub node_id: String,
pub tenant_id: String,
pub cluster_id: String,
pub core_id: String,
pub operation_mode: String,
pub storage_status: String,
pub security_ok: bool,
pub api_enabled: bool,
pub sync_enabled: bool,
pub sync_role: String,
pub sync_log_len: usize,
pub sync_log_path: Option<String>,
pub sync_checkpoint_path: Option<String>,
pub sync_peers: Vec<String>,
pub sync_dns_enabled: bool,
pub sync_dns_seeds: Vec<String>,
pub sync_dns_default_port: u16,
pub idempotency_ttl_ms: u64,
pub idempotency_path: Option<String>,
}Expand description
Non-sensitive Runtime facts exposed by health and status routes.
Fields
app_id: StringApplication identity hosted by this process.
node_id: StringRuntime node identity.
tenant_id: StringTenant isolation boundary.
cluster_id: StringCluster isolation boundary.
core_id: StringLogical Core identity.
operation_mode: StringInitial operational-mode label.
storage_status: StringStorage provider health label.
security_ok: boolWhether required security material initialized successfully.
api_enabled: boolWhether HTTP ingress is enabled.
sync_enabled: boolWhether synchronization is enabled.
sync_role: StringLocal synchronization role.
sync_log_len: usizeNumber of records currently visible in the sync log.
sync_log_path: Option<String>Optional sync-log path for local diagnostics.
sync_checkpoint_path: Option<String>Optional sync-checkpoint path for local diagnostics.
sync_peers: Vec<String>Configured peer addresses without credentials.
sync_dns_enabled: boolWhether DNS peer discovery is enabled.
sync_dns_seeds: Vec<String>Configured DNS peer seeds.
sync_dns_default_port: u16Default port applied to DNS seeds.
idempotency_ttl_ms: u64Idempotency retention window in milliseconds.
idempotency_path: Option<String>Optional idempotency-store path for local diagnostics.