Module http

Module http 

Minimal HTTP host for runtime health, status, and command ingress.

Structs

HttpApiConfig
Runtime HTTP listener and request-size configuration.
HttpCommandAuth
Bearer-token requirements and verifier for HTTP Runtime routes.
RequestValidationDetails
Details of an incoming query or command request used to verify its integrity.
RuntimeHttpHost
Embedded HTTP host for stable Runtime health, status, command, and query routes.
RuntimeHttpStateParts
Optional shared state used to compose a RuntimeHttpHost.
RuntimeStaticInfo
Non-sensitive Runtime facts exposed by health and status routes.

Enums

CommandCapabilityPolicyError
Stable reason a capability policy rejected a command.

Traits

CommandCapabilityPolicy
Authorizes command execution against capability and leadership policy.
CommandTokenVerifier
Verifies command- and query-scoped bearer tokens.
SyncLogView
Read-only synchronization-log metrics exposed to the HTTP host.